<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="docs/images/porringer-dark.svg">
    <source media="(prefers-color-scheme: light)" srcset="docs/images/porringer-light.svg">
    <img width=25% alt="Porringer Logo" src="docs/images/porringer-light.svg">
  </picture>
  <br>
  <em>A meta-package manager for all porridges</em>
</p>

# Porringer

A CLI and API that can discover and orchestrate multiple underlying package managers through a plugin system.

[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](LICENSE.md)
[![PyPI version](https://img.shields.io/pypi/v/porringer.svg)](https://pypi.org/project/porringer/)

## Features

## Setup

See [Setup](https://synodic.github.io/porringer/setup) for setup instructions.

## Development

We use [pdm](https://pdm-project.org/en/latest/) as our build system and package manager. Scripts for development tasks are defined in `pyproject.toml` under the `[tool.pdm.scripts]` section.

See [Development](https://synodic.github.io/porringer/development) for additional build, test, and installation instructions.

For contribution guidelines, see [CONTRIBUTING.md](https://github.com/synodic/.github/blob/stable/CONTRIBUTING.md).

## Documentation

## License

This project is licensed under the MIT License — see [LICENSE.md](LICENSE.md) for details.

Copyright © 2025 Synodic Software
